@@ -11,8 +11,6 @@ import shutil
 import subprocess
 import tempfile
 import time
-import doctest
-import unittest
 
 # There are two ways PIL is packaged
 try:
@@ -21,7 +19,7 @@ except ImportError:
     import Image, ImageDraw, ImageChops, ImageFilter
 
 
-__version__ = "1.5.0"
+__version__ = "1.6.0"
 
 
 def parse_color(color):
@@ -82,10 +80,15 @@ class MyOption(optparse.Option):
     TYPE_CHECKER["color"] = check_color
 
 
-def main():
+def main(argv=None):
+    prog = args = None
+    if argv is not None:
+        prog = os.path.basename(sys.argv[0])
+        args = argv[1:]
+
     parser = optparse.OptionParser('%prog [options] image1 image2',
                 description='Compare two images side-by-side',
-                option_class=MyOption)
+                option_class=MyOption, prog=prog)
 
     parser.add_option('-o', dest='outfile',
                       help='write the combined image to a file')
@@ -103,7 +106,7 @@ def main():
                       help='highlight differences in a smarter way (EXPERIMENTAL)')
     parser.add_option('--opacity', type='int', default='64',
                       help='minimum opacity for highlighting (default %default)')
-    parser.add_option('--timeout', type='int', default='10',
+    parser.add_option('--timeout', type='float', default='10',
                       help='skip highlighting if it takes too long'
                            ' (default: %default seconds)')
 
@@ -126,14 +129,7 @@ def main():
     parser.add_option('--border', type='int', default=0, metavar='N',
                       help='border around images (default: %default pixels)')
 
-    parser.add_option('--selftest', action='store_true',
-                      help='run unit tests')
-
-    opts, args = parser.parse_args()
-
-    if opts.selftest:
-        sys.argv[1:] = args
-        run_tests() # calls sys.exit()
+    opts, args = parser.parse_args(args)
 
     if len(args) != 2:
         parser.error('expecting two arguments, got %d' % len(args))
@@ -249,7 +245,7 @@ def spawn_viewer(viewer, img, filename, grace):
     before removing the temporary file.  Useful if your viewer forks
     into background before it opens the file.
     """
-    tempdir = tempfile.mkdtemp('imgdiff')
+    tempdir = tempfile.mkdtemp(prefix='imgdiff-')
     try:
         imgfile = os.path.join(tempdir, filename)
         img.save(imgfile)
@@ -277,16 +273,16 @@ def tweak_diff(diff, opacity):
     return mask
 
 
-def diff(img1, img2, (x1, y1), (x2, y2)):
+def diff(img1, img2, x1y1, x2y2):
     """Compare two images with given alignments.
 
     Returns a difference map.
 
-    ``(x1, y1)`` specify the top-left corner of the aligned area with respect
-    to ``img1``.
+    ``x1y1``: a tuple ``(x1, y1)`` to specify the top-left corner of the
+    aligned area with respect to ``img1``.
 
-    ``(x2, y2)`` specify the top-left corner of the aligned area with respect
-    to ``img2``.
+    ``x2y2``: a tuple ``(x2, y2)`` to specify the top-left corner of
+    the aligned area with respect to ``img2``.
 
     Either ``x1`` or ``x2`` must be 0, depending on whether ``img1`` is
     narrower or wider than ``img2``.  Both must be 0 if the two images
@@ -338,6 +334,8 @@ def diff(img1, img2, (x1, y1), (x2, y2)):
     If ``img1`` is narrower but taller than ``img2``, just swap the labels
     in the description above.
     """
+    x1, y1 = x1y1
+    x2, y2 = x2y2
     w1, h1 = img1.size
     w2, h2 = img2.size
     w, h = min(w1, w2), min(h1, h2)
@@ -400,7 +398,7 @@ class Progress(object):
             self._say('Highlighting takes too long: timed out after %.0f seconds'
                       % self.timeout)
             raise Timeout
-        if time.time() - self.started > self.delay:
+        if time.time() - self.started >= self.delay:
             self._say_if_terminal('%d%% (%d out of %d %s)'
                                   % (self.position * 100 // self.total,
                                      self.position, self.total, self.what))
@@ -413,7 +411,7 @@ class Progress(object):
             self.shown = False
 
 
-def best_diff(img1, img2):
+def best_diff(img1, img2, opts):
     """Find the best alignment of two images that minimizes the differences.
 
     Returns (diff, alignments) where ``diff`` is a difference map, and
@@ -430,7 +428,7 @@ def best_diff(img1, img2):
     xr = abs(w1 - w2) + 1
     yr = abs(h1 - h2) + 1
 
-    p = Progress(xr * yr)
+    p = Progress(xr * yr, timeout=opts.timeout)
     for x in range(xr):
         if w1 > w2:
             x1, x2 = x, 0
@@ -463,7 +461,7 @@ def simple_highlight(img1, img2, opts):
     """
 
     try:
-        diff, ((x1, y1), (x2, y2)) = best_diff(img1, img2)
+        diff, ((x1, y1), (x2, y2)) = best_diff(img1, img2, opts)
     except KeyboardInterrupt:
         return None, None
     diff = diff.filter(ImageFilter.MaxFilter(9))
@@ -520,7 +518,7 @@ def slow_highlight(img1, img2, opts):
     yr = abs(h1 - h2) + 1
 
     try:
-        p = Progress(xr * yr)
+        p = Progress(xr * yr, timeout=opts.timeout)
         for x in range(xr):
             for y in range(yr):
                 p.next()
@@ -553,18 +551,5 @@ def slow_highlight(img1, img2, opts):
     return mask1, mask2
 
 
-def test_suite():
-    """Collect all the tests into a test suite."""
-    return doctest.DocTestSuite()
-
-
-def run_tests():
-    """Run the test suite.
-
-    Invokes sys.exit() with a zero or non-zero status code as appropriate
-    """
-    unittest.main(defaultTest='test_suite')
-
-
 if __name__ == '__main__':
     main()
